summaryrefslogtreecommitdiff
path: root/opcode.h
diff options
context:
space:
mode:
Diffstat (limited to 'opcode.h')
-rw-r--r--opcode.h16
1 files changed, 15 insertions, 1 deletions
diff --git a/opcode.h b/opcode.h
index 3a08dfae22..decd14710c 100644
--- a/opcode.h
+++ b/opcode.h
@@ -561,6 +561,8 @@ EXTCONST char* const PL_op_name[] = {
"blessed",
"refaddr",
"reftype",
+ "ceil",
+ "floor",
"freed",
};
#endif
@@ -981,6 +983,8 @@ EXTCONST char* const PL_op_desc[] = {
"blessed",
"refaddr",
"reftype",
+ "ceil",
+ "floor",
"freed op",
};
#endif
@@ -1404,6 +1408,8 @@ EXT Perl_ppaddr_t PL_ppaddr[] /* or perlvars.h */
Perl_pp_blessed,
Perl_pp_refaddr,
Perl_pp_reftype,
+ Perl_pp_ceil,
+ Perl_pp_floor,
}
#endif
;
@@ -1823,6 +1829,8 @@ EXT Perl_check_t PL_check[] /* or perlvars.h */
Perl_ck_null, /* blessed */
Perl_ck_null, /* refaddr */
Perl_ck_null, /* reftype */
+ Perl_ck_null, /* ceil */
+ Perl_ck_null, /* floor */
}
#endif
;
@@ -2243,6 +2251,8 @@ EXTCONST U32 PL_opargs[] = {
0x00000106, /* blessed */
0x0000011e, /* refaddr */
0x0000011e, /* reftype */
+ 0x0000011e, /* ceil */
+ 0x0000011e, /* floor */
};
#endif
@@ -2922,6 +2932,8 @@ EXTCONST I16 PL_op_private_bitdef_ix[] = {
49, /* blessed */
75, /* refaddr */
75, /* reftype */
+ 75, /* ceil */
+ 75, /* floor */
};
@@ -2961,7 +2973,7 @@ EXTCONST U16 PL_op_private_bitdefs[] = {
0x117c, 0x22b8, 0x09b4, 0x40ec, 0x2648, 0x4864, 0x07c1, /* trans, transr */
0x0fbc, 0x04d8, 0x0067, /* sassign */
0x0c78, 0x0b74, 0x0a70, 0x31cc, 0x05a8, 0x0067, /* aassign */
- 0x4630, 0x0003, /* chomp, schomp, scomplement, sin, cos, exp, log, sqrt, int, hex, oct, abs, ord, chr, chroot, rmdir, isbool, isweak, refaddr, reftype */
+ 0x4630, 0x0003, /* chomp, schomp, scomplement, sin, cos, exp, log, sqrt, int, hex, oct, abs, ord, chr, chroot, rmdir, isbool, isweak, refaddr, reftype, ceil, floor */
0x05b4, 0x31cc, 0x0003, /* pos */
0x4630, 0x0067, /* pow, multiply, i_multiply, divide, i_divide, modulo, i_modulo, add, i_add, subtract, i_subtract */
0x1538, 0x0067, /* repeat */
@@ -3433,6 +3445,8 @@ EXTCONST U8 PL_op_private_valid[] = {
/* BLESSED */ (OPpARG1_MASK|OPpMAYBE_TRUEBOOL|OPpTRUEBOOL),
/* REFADDR */ (OPpARG1_MASK|OPpTARGET_MY),
/* REFTYPE */ (OPpARG1_MASK|OPpTARGET_MY),
+ /* CEIL */ (OPpARG1_MASK|OPpTARGET_MY),
+ /* FLOOR */ (OPpARG1_MASK|OPpTARGET_MY),
};